"use strict";
// @ts-nocheck
/**
 *
 * **/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.crawlForFiles = exports.locateFilePath = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const constants_1 = require("./constants");
const formatters_1 = require("./formatters");
/**
 * Locate a file's path based on it's slug
 * @param {object} options
 * @returns `string` path of the located file
 */
function locateFilePath(options) {
    // options structure
    // const struct = {
    // 	// either a path or a slug is required, but not both. Path will supersede the slug, since it is faster
    // 	path: "",
    // 	slug: "",
    // 	basePath: null, // base directory, inside of BASE_PATH
    // };
    // convert the `options` into an object
    if (typeof options === "string")
        options = { slug: options };
    if (!(options === null || options === void 0 ? void 0 : options.slug))
        return false;
    // construct the base working path to search
    if (!(options === null || options === void 0 ? void 0 : options.basePath))
        options.basePath = path_1.default.join(constants_1.BASE_PATH);
    //   options.basePath = path.join(BASE_PATH, options.basePath);
    // try file based routing first, since it's the fastest
    if ((options === null || options === void 0 ? void 0 : options.slug) &&
        fs_1.default.existsSync(path_1.default.join(options.basePath, `${options === null || options === void 0 ? void 0 : options.slug}.md`)))
        return path_1.default.join(options.basePath, `${options === null || options === void 0 ? void 0 : options.slug}.md`);
    // when not found in file based routing, begin crawling...
    const files = crawlForFiles(options.basePath, true) || [];
    const file = (files === null || files === void 0 ? void 0 : files.filter((item) => {
        if (!item)
            return false;
        // TODO: I think there are more ways to accept the slugs here...
        if ((item === null || item === void 0 ? void 0 : item.slug) && (options === null || options === void 0 ? void 0 : options.slug) && item.slug === options.slug)
            return item;
        else if ((0, formatters_1.generateSlug)(item) === ((options === null || options === void 0 ? void 0 : options.slug) || (0, formatters_1.generateSlug)(options === null || options === void 0 ? void 0 : options.path)))
            return item;
        return false;
    })[0]) || false;
    if (file && fs_1.default.existsSync(path_1.default.join(file)))
        return path_1.default.join(file);
    else
        return false;
}
exports.locateFilePath = locateFilePath;
/**
 * Crawl a given directory to locate all of the files in in
 * @param {string} dirName String name of the directory to crawl
 * @param {boolean} autoParseFile
 * @param {boolean} drafts
 * @returns array of file paths, and when `autoParseFile` is true returns an array of file paths with their file parsed
 */
function crawlForFiles(dirName = "", autoParseFile = true, drafts = false) {
    var _a, _b, _c;
    let files = [];
    // only resolve in the `BASE_PATH` directory
    if (!(dirName === null || dirName === void 0 ? void 0 : dirName.startsWith(path_1.default.resolve(constants_1.BASE_PATH))))
        dirName = path_1.default.resolve(path_1.default.join(constants_1.BASE_PATH, dirName));
    try {
        // ensure the root `dirName` actually exists
        if (!fs_1.default.existsSync(dirName))
            return false;
        // read in the desired directory
        let listing = fs_1.default.readdirSync(dirName, { withFileTypes: true });
        // crawl the search directory for more files
        for (let i = 0; i < listing.length; i++) {
            const pointer = path_1.default.join(dirName, (_a = listing[i]) === null || _a === void 0 ? void 0 : _a.name);
            // prevent crawling files/dirs with names starting with "_"
            if ((_c = (_b = listing[i]) === null || _b === void 0 ? void 0 : _b.name) === null || _c === void 0 ? void 0 : _c.startsWith("_"))
                continue;
            // recursively crawl child directories
            if (listing[i].isDirectory()) {
                files.push(...crawlForFiles(pointer, autoParseFile));
            }
            else if (listing[i].isFile()) {
                // TODO: add checking to only search for the given file extensions
                files.push(pointer);
            }
        }
    }
    catch (err) {
        console.warn("[error] crawlForFiles:", err);
    }
    return files;
}
exports.crawlForFiles = crawlForFiles;
//# sourceMappingURL=fs.js.map