"use strict";
// @ts-nocheck
/**
 *
 * **/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateStaticPaths = exports.generateStaticPaths = void 0;
const path_1 = __importDefault(require("path"));
const constants_1 = require("./constants");
const formatters_1 = require("./formatters");
const fs_1 = require("./fs");
/**
 * Generate a valid Next.JS `getStaticPaths` object that is plug-and-play
 * @param {array|string} files name of the directory to crawl, or an array listing of an already crawled directory
 * @param {boolean} drafts whether or not to include items that are marked as `draft: true` in their front-matter
 * @returns a valid Next.JS `getStaticPaths` object
 */
function generateStaticPaths(files = null, drafts = false) {
    var _a, _b, _c, _d;
    const paths = [];
    // when 'files' is a string => auto crawl that directory
    if (typeof files === "string")
        files = (0, fs_1.crawlForFiles)(path_1.default.resolve(constants_1.BASE_PATH, files));
    if (!files || !Array.isArray(files))
        return paths;
    for (let i = 0; i < files.length; i++) {
        const item = {
            params: {
                slug: (0, formatters_1.generateSlug)(((_a = files[i]) === null || _a === void 0 ? void 0 : _a.slug) || files[i]),
            },
        };
        // add the `item` to the paths listing (handling desired draft states)
        if (drafts === true ||
            (((_b = files[i]) === null || _b === void 0 ? void 0 : _b.draft) !== false && ((_d = (_c = files[i]) === null || _c === void 0 ? void 0 : _c.meta) === null || _d === void 0 ? void 0 : _d.draft) !== false))
            paths.push(item);
    }
    return {
        paths: paths,
        fallback: false,
    };
}
exports.generateStaticPaths = generateStaticPaths;
/**
 * Generate a valid Next.JS `getStaticPaths` object for paginated pages that is plug-and-play
 * @param {object} pagination object computed from `computePagination`
 * @returns a valid Next.JS `getStaticPaths` object
 */
function paginateStaticPaths(pagination) {
    let paths = [];
    // perform basic validation of the `pagination` object
    if ((pagination === null || pagination === void 0 ? void 0 : pagination.totalPages) && (pagination === null || pagination === void 0 ? void 0 : pagination.template) && (pagination === null || pagination === void 0 ? void 0 : pagination.baseHref)) {
        // parse each of the items
        for (let i = 2; i <= pagination.totalPages; i++) {
            paths.push((0, formatters_1.parseTemplate)(pagination.template, {
                baseHref: pagination.baseHref,
                id: i,
            }));
        }
    }
    return { paths, fallback: true };
}
exports.paginateStaticPaths = paginateStaticPaths;
//# sourceMappingURL=next.js.map