/**
 *
 * **/
/**
 * Retrieve a markdown document from the `content` directory, parsed and ready to go
 * @param {string} slug slug of the file name to locate
 * @param {string} basePath (optional) folder path inside of the `content` folder to search for the given slug
 * @returns
 */
export declare function getDocBySlug(slug: any, basePath?: string): Promise<false | {
    path: any;
    href: null;
    slug: null;
    meta: any;
    content: any;
}>;
/**
 * Compute the absolute href of a given doc
 * @param {object} doc full doc or doc.meta data object
 * @param {string} basePath string of the base bath used to locate the doc
 * @returns string of the absolute href for the given doc
 */
export declare function computeHrefForDoc(doc: any, basePath: any): any;
/**
 * Retrieve a markdown document's front matter meta, parsed and ready to go
 * @param {string} slug slug of the file name to locate
 * @param {string} basePath (optional) folder path inside of the `content` folder to search for the given slug
 * @returns
 */
export declare function getDocMetaBySlug(slug: any, basePath?: string): Promise<false | {
    path: any;
    href: null;
    slug: null;
    meta: any;
    content: any;
}>;
/**
 * Retrieve a listing of markdown documents from the given `searchPath` directory, parsed and ready to go
 * @param {string} searchPath base relative path of documents to locate
 * @param {object} options custom options to use on the docs
 * @returns `array` of documents located inside the `searchPath`
 */
export declare function getDocsByPath(searchPath?: string, options?: {}): Promise<any>;
/**
 * Load and parse a the file from the given `filePath`, making it ready for the frontend.
 * @param {string} filePath path to the file to load and parse
 * @param {boolean} metaOnly whether or not to only parse/return the meta data
 * @returns
 */
export declare function loadAndParseDoc(filePath: any, metaOnly?: boolean): Promise<false | {
    path: any;
    href: null;
    slug: null;
    meta: any;
    content: any;
}>;
/**
 * Filter a listing of documents by the provided `filter` criteria on the `doc.meta` data
 * @param {array} docs array of documents to be filtered
 * @param {object} filters criteria to filter by
 * @param {number} limit max number of filtered documents to return
 * @returns
 */
export declare function filterDocs(docs: any, filters: any, limit?: number): any;
//# sourceMappingURL=docs.d.ts.map