/**
 *
 * **/
export declare function generateSlug(item: any): string;
/**
 * Parse and return a `string` template
 * @param {string} template string to parse
 * @param {object} items keyed object of items to parse into the `template`
 * @returns fully parsed `template`
 */
export declare function parseTemplate(template: any, items: any): any;
/**
 * Determine a docs' primary date based on the standard priority order of: `date`, `updatedAt`, `createdAt`
 * @param {object} listing Object listing of the posts dates
 */
export declare function getDateByPriority({ date, updatedAt, createdAt, }: {
    date?: null | undefined;
    updatedAt?: null | undefined;
    createdAt?: null | undefined;
}): boolean;
/**
 * Sorts a listing of docs by their priority date
 * @param {array} docs array listing of parsed `doc` objects
 * @param {string} order `asc` or `desc` sort order
 * @returns sorted array
 */
export declare function sortByPriorityDate(docs: any, order?: string): any;
/**
 * Compute the required parameters used in pagination
 * @param {number} count total number of items to paginate
 * @param {number} page the current page of items to parse
 * @param {string} baseHref the base `href` used in creating routes
 * @param {string} template template string used for `href`
 * @param {number} perPage number of items desired per page
 * @returns `pagination` object ready to be used
 */
export declare function computePagination(count?: number, page?: number, baseHref?: string, template?: string, perPage?: number): false | {
    count: number;
    page: number;
    perPage: number;
    totalPages: number;
    baseHref: string;
    template: string;
};
/**
 * Format and display the given date using the standard format
 * @param {string} date date to display in a common format
 * @param {string|null} format `DateTime` compatible date format
 * @returns formatted date string, ready for display
 */
export declare function displayDate(date: any, format?: null): string;
/**
 * Convert any string date into a unix timestamp
 * @param {string} date
 * @returns int of the unix timestamp
 */
export declare function dateToUnixTimestamp(date: any): number;
//# sourceMappingURL=formatters.d.ts.map